# eric7.PluginManager.PluginExceptions

Module implementing the exceptions raised by the plugin system.

### Global Attributes

None

### Classes

PluginActivationError | Class defining an error raised, when there was an error during plugin activation.
PluginClassFormatError | Class defining an error raised, when the plugin module's class is invalid.
PluginError | Class defining a special error for the plugin classes.
PluginLoadError | Class defining an error raised, when there was an error during plugin loading.
PluginModuleFormatError | Class defining an error raised, when the plugin module is invalid.
PluginModulesError | Class defining an error raised, when no plugin modules were found.
PluginPathError | Class defining an error raised, when the plugin paths were not found and could not be created.

### Functions

None

## PluginActivationError

Class defining an error raised, when there was an error during plugin activation.

### Derived from

PluginError

### Class Attributes

None

### Class Methods

None

### Methods

PluginActivationError | Constructor

### Static Methods

None

#### PluginActivationError (Constructor)

PluginActivationError(name)

Constructor

name
  name of the plugin module (string)

Up

## PluginClassFormatError

Class defining an error raised, when the plugin module's class is invalid.

### Derived from

PluginError

### Class Attributes

None

### Class Methods

None

### Methods

PluginClassFormatError | Constructor

### Static Methods

None

#### PluginClassFormatError (Constructor)

PluginClassFormatError(name, class_, missing)

Constructor

name
  name of the plugin module (string)
class_
  name of the class not satisfying the requirements (string)
missing
  description of the missing element (string)

Up

## PluginError

Class defining a special error for the plugin classes.

### Derived from

Exception

### Class Attributes

None

### Class Methods

None

### Methods

PluginError | Constructor
__repr__ | Special method returning a representation of the exception.
__str__ | Special method returning a string representation of the exception.

### Static Methods

None

#### PluginError (Constructor)

PluginError()

Constructor

#### PluginError.__repr__

__repr__()

Special method returning a representation of the exception.

Return:
  string representing the error message

#### PluginError.__str__

__str__()

Special method returning a string representation of the exception.

Return:
  string representing the error message

Up

## PluginLoadError

Class defining an error raised, when there was an error during plugin loading.

### Derived from

PluginError

### Class Attributes

None

### Class Methods

None

### Methods

PluginLoadError | Constructor

### Static Methods

None

#### PluginLoadError (Constructor)

PluginLoadError(name)

Constructor

name
  name of the plugin module (string)

Up

## PluginModuleFormatError

Class defining an error raised, when the plugin module is invalid.

### Derived from

PluginError

### Class Attributes

None

### Class Methods

None

### Methods

PluginModuleFormatError | Constructor

### Static Methods

None

#### PluginModuleFormatError (Constructor)

PluginModuleFormatError(name, missing)

Constructor

name
  name of the plugin module (string)
missing
  description of the missing element (string)

Up

## PluginModulesError

Class defining an error raised, when no plugin modules were found.

### Derived from

PluginError

### Class Attributes

None

### Class Methods

None

### Methods

PluginModulesError | Constructor

### Static Methods

None

#### PluginModulesError (Constructor)

PluginModulesError()

Constructor

Up

## PluginPathError

Class defining an error raised, when the plugin paths were not found and could not be created.

### Derived from

PluginError

### Class Attributes

None

### Class Methods

None

### Methods

PluginPathError | Constructor

### Static Methods

None

#### PluginPathError (Constructor)

PluginPathError(msg=None)

Constructor

msg
  message to be used by the exception (string)

Up